Unit Bass_VST;

interface

{$IFDEF MSWINDOWS}
uses BASS, Windows;
{$ELSE}
uses BASS;
{$ENDIF}


const
  BASS_VST_KEEP_CHANS = 1;

  BASS_VST_PARAM_CHANGED = 1;
  BASS_VST_EDITOR_RESIZED = 2;
  BASS_VST_AUDIO_MASTER = 3;

  BASS_VST_ERROR_NOINPUTS     = 3000; // the given effect has no inputs and is probably a VST instrument and no effect
  BASS_VST_ERROR_NOOUTPUTS    = 3001; // the given effect has no outputs
  BASS_VST_ERROR_NOREALTIME   = 3002; // the given effect does not support realtime processing


type

BASS_VST_PARAM_INFO = record
    name:  array [0..15] of AnsiChar;     // examples: Time, Gain, RoomType
    unit_: array [0..15] of AnsiChar;     // examples: sec, dB, type
    display: array [0..15] of AnsiChar;   // the current value in a readable format, examples: 0.5, -3, PLATE
    defaultValue: single;                 // the default value
end;

BASS_VST_INFO = record
    channelHandle: DWORD;                 // the channelHandle as given to BASS_VST_ChannelSetDSP()
    uniqueID: DWORD;                      // a unique ID for the effect (the IDs are registered at Steinberg)
    effectName: array [0..79] of AnsiChar;    // the effect name
    effectVersion: DWORD;                 // the effect version
    effectVstVersion: DWORD;              // the VST version, the effect was written for
    hostVstVersion: DWORD;                // the VST version supported by BASS_VST, currently 2.4
    productName: array [0..79] of AnsiChar;   // the product name, may be empty
    vendorName: array [0..79] of AnsiChar;     // the vendor name, may be empty
    vendorVersion: DWORD;                 // vendor-specific version number
    chansIn: DWORD;                       // max. number of possible input channels
    chansOut: DWORD;                      // max. number of possible output channels
    initialDelay: DWORD;                  // for algorithms which need input in the first place, in milliseconds
    hasEditor: DWORD;                     // can the BASS_VST_EmbedEditor() function be called?
    editorWidth: DWORD;                   // initial/current width of the editor, also note BASS_VST_EDITOR_RESIZED
    editorHeight: DWORD;                  // initial/current height of the editor, also note BASS_VST_EDITOR_RESIZED
    aeffect: Pointer;                     // the underlying AEffect object (see the VST SDK)
    isInstrument: DWORD;                  // 1=the VST plugin is an instrument, 0=the VST plugin is an effect
    dspHandle: DWORD;                     // the internal DSP handle
end;


VSTPROC = function(vstHandle: DWORD; Action: DWORD; Param1,Param2,User: DWORD): DWORD; {$IFDEF MSWINDOWS}stdcall{$ELSE}cdecl{$ENDIF};

{$IFDEF MSWINDOWS}
  bass_vstdll = 'bass_vst.dll';
{$ENDIF}
{$IFDEF MACOS}
  bass_vstdll = 'libbass_vst.dylib';
{$ENDIF}

function BASS_VST_ChannelSetDSP(Channel: DWORD; const DLLFile: PChar; flags: DWORD; priority: Integer): DWORD; {$IFDEF MSWINDOWS}stdcall{$ELSE}cdecl{$ENDIF}; external bass_vstdll;
function BASS_VST_ChannelSetDSPEx(Channel: DWORD; const DLLFile: PChar; flags: DWORD; priority: Integer; pluginList: PAnsiChar; pluginListSize,pluginID: Integer): DWORD; {$IFDEF MSWINDOWS}stdcall{$ELSE}cdecl{$ENDIF}; external bass_vstdll;
function BASS_VST_ChannelRemoveDSP(Channel: DWORD; vstHandle: DWORD): BOOL; {$IFDEF MSWINDOWS}stdcall{$ELSE}cdecl{$ENDIF}; external bass_vstdll;

function BASS_VST_EmbedEditor(Channel: DWORD; ParentWindow: hwnd): BOOL; {$IFDEF MSWINDOWS}stdcall{$ELSE}cdecl{$ENDIF}; external bass_vstdll;

function BASS_VST_GetInfo(VSTHandle: DWORD; pInfo: Pointer): BOOL; {$IFDEF MSWINDOWS}stdcall{$ELSE}cdecl{$ENDIF}; external bass_vstdll;
function BASS_VST_GetParam(vstHandle: DWORD; paramIndex: integer): single; {$IFDEF MSWINDOWS}stdcall{$ELSE}cdecl{$ENDIF}; external bass_vstdll;
function BASS_VST_SetParam(vstHandle: DWORD; paramIndex: integer; value: single): BOOL; {$IFDEF MSWINDOWS}stdcall{$ELSE}cdecl{$ENDIF}; external bass_vstdll;
function BASS_VST_GetParamCount(vstHandle: DWORD): integer; {$IFDEF MSWINDOWS}stdcall{$ELSE}cdecl{$ENDIF}; external bass_vstdll;
function BASS_VST_GetParamInfo(vstHandle: DWORD; paramIndex: Integer; var Info: BASS_VST_PARAM_INFO): BOOL; {$IFDEF MSWINDOWS}stdcall{$ELSE}cdecl{$ENDIF}; external bass_vstdll;
function BASS_VST_GetChunk(vstHandle: DWORD; isPreset: BOOL; var length: DWORD): BOOL; {$IFDEF MSWINDOWS}stdcall{$ELSE}cdecl{$ENDIF}; external bass_vstdll;
function BASS_VST_Resume(vstHandle: DWORD): BOOL; {$IFDEF MSWINDOWS}stdcall{$ELSE}cdecl{$ENDIF}; external bass_vstdll;
function BASS_VST_SetCallback(vstHandle: DWORD; proc: VSTPROC; user: DWORD): BOOL; {$IFDEF MSWINDOWS}stdcall{$ELSE}cdecl{$ENDIF}; external bass_vstdll;
function BASS_VST_SetLanguage(const Lang: PChar): BOOL; {$IFDEF MSWINDOWS}stdcall{$ELSE}cdecl{$ENDIF}; external bass_vstdll;
function BASS_VST_SetBypass(vstHandle: DWORD; state: BOOL): BOOL; {$IFDEF MSWINDOWS}stdcall{$ELSE}cdecl{$ENDIF}; external bass_vstdll;
function BASS_VST_GetBypass(vstHandle: DWORD): dword; {$IFDEF MSWINDOWS}stdcall{$ELSE}cdecl{$ENDIF}; external bass_vstdll;

function BASS_VST_ChannelCreate(freq: DWORD; chans: DWORD; const DLLFile: PChar; flags: DWORD): DWORD; {$IFDEF MSWINDOWS}stdcall{$ELSE}cdecl{$ENDIF}; external bass_vstdll;
function BASS_VST_ChannelCreateEx(freq: DWORD; chans: DWORD; const DLLFile: PChar; flags: DWORD; pluginList: PAnsiChar; pluginListSize,pluginID: Integer): DWORD; {$IFDEF MSWINDOWS}stdcall{$ELSE}cdecl{$ENDIF}; external bass_vstdll;
function BASS_VST_ChannelFree(vstHandle: DWORD): BOOL; {$IFDEF MSWINDOWS}stdcall{$ELSE}cdecl{$ENDIF}; external bass_vstdll;
function BASS_VST_ProcessEvent(vstHandle: DWORD; midiCh: DWORD; event: DWORD; param: DWORD): BOOL; {$IFDEF MSWINDOWS}stdcall{$ELSE}cdecl{$ENDIF}; external bass_vstdll;
function BASS_VST_ProcessEventRaw(vstHandle: DWORD; event: pointer; length: DWORD): BOOL; {$IFDEF MSWINDOWS}stdcall{$ELSE}cdecl{$ENDIF}; external bass_vstdll;

function BASS_VST_GetProgramCount(vstHandle: DWORD): Integer; {$IFDEF MSWINDOWS}stdcall{$ELSE}cdecl{$ENDIF}; external bass_vstdll;
function BASS_VST_GetProgram(vstHandle: DWORD): Integer; {$IFDEF MSWINDOWS}stdcall{$ELSE}cdecl{$ENDIF}; external bass_vstdll;
function BASS_VST_SetProgram(vstHandle: DWORD; programIndex: Integer): BOOL; {$IFDEF MSWINDOWS}stdcall{$ELSE}cdecl{$ENDIF}; external bass_vstdll;
function BASS_VST_GetProgramParam(vstHandle: DWORD; programIndex: Integer; var length: DWORD): PSingle; {$IFDEF MSWINDOWS}stdcall{$ELSE}cdecl{$ENDIF}; external bass_vstdll;
function BASS_VST_SetProgramParam(vstHandle: DWORD; programIndex: Integer; param: PSingle; length: DWORD): BOOL; {$IFDEF MSWINDOWS}stdcall{$ELSE}cdecl{$ENDIF}; external bass_vstdll;
function BASS_VST_GetProgramName(vstHandle: DWORD; programIndex: Integer): PAnsiChar; {$IFDEF MSWINDOWS}stdcall{$ELSE}cdecl{$ENDIF}; external bass_vstdll;
function BASS_VST_SetProgramName(vstHandle: DWORD; programIndex: Integer; name: PAnsiChar): BOOL; {$IFDEF MSWINDOWS}stdcall{$ELSE}cdecl{$ENDIF}; external bass_vstdll;

implementation

end.